﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Steema.TeeChart.Styles;

namespace TChartTest1
{
    public partial class Form1 : Form
    {
        private int counter = 0;
        private SeriesValue sValue = new SeriesValue();
        private int maxData = 1000;
        private Random random = new Random();

        public Form1()
        {
            InitializeComponent();

            Process p = Process.GetCurrentProcess();
            this.Text = p.Id.ToString();

            tChart1.Text = "My Chart Text";
            tChart1.Aspect.View3D = false;

            tChart1.Axes.Bottom.AutomaticMinimum = false;
            tChart1.Axes.Bottom.AutomaticMaximum = false;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            for (int i = 0; i < tChart1.Series.Count; i++)
            {
                tChart1.Series[i].Labels.Clear();
            }
            tChart1.Series.Clear();

            int seriesCount = 2;
            if (radioButton2.Checked)
                seriesCount = 30;

            for (int i = 0; i < seriesCount; i++)
            {
                FastLine fl1 = new FastLine();
                fl1.Title = "My Line " + (i + 1).ToString();
                //fl1.Color = Color.Blue;
                fl1.Color = Color.FromKnownColor((KnownColor) (random.Next(139) + 27));

                tChart1.Series.Add(fl1);
            }
            System.Diagnostics.Debug.WriteLine("Series Count:" + tChart1.Series.Count);

            timer1.Start();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            timer1.Stop();
        }

        private void OnTimerTick(object sender, EventArgs e)
        {
            //long startTime1 = DateTime.Now.Ticks;
            DateTime dt = DateTime.Now;
            counter++;

            if (counter > maxData)
            {
                counter = 1;
            }

            int seriesCount = tChart1.Series.Count;
            int seriesIndex = random.Next(seriesCount);
            int dataValue = random.Next(maxData);

            // tChart1.Series[n].Add(dt, tChart1.Series[n].XValues.Count + 1);
            tChart1.Series[seriesIndex].Add(dt, dataValue);

            // Loop thru the Series to check which Series 
            for (int i = 0; i < seriesCount; i++)
            {
                if (tChart1.Series[i].XValues.Count > maxData)
                {
                    tChart1.Series[i].XValues.RemoveAt(0);
                    tChart1.Series[i].YValues.RemoveAt(0);
                }
            }

            UpdateTimeAxis(dt);

            ReFormatXTimeAxis();


            for (int i = 0; i < seriesCount; i++)
            {
                System.Diagnostics.Debug.Write("Series" + i + ": " + tChart1.Series[i].XValues.Count + "(" + tChart1.Series[i].Labels.Count + "), ");
            }
            System.Diagnostics.Debug.WriteLine("");

        }

        private void OnFormLoad(object sender, EventArgs e)
        {
            radioButton1.Checked = true;
        }

        private void UpdateTimeAxis(DateTime maxTime)
        {
            //System.Diagnostics.Debug.WriteLine("UpdateTimeAxis");

            DateTime minScrollDateTime = maxTime.Subtract(new TimeSpan(0, 0, 10));
            tChart1.Axes.Bottom.Minimum = minScrollDateTime.ToOADate();
            tChart1.Axes.Bottom.Maximum = maxTime.ToOADate();
        }

        private void ReFormatXTimeAxis()
        {
            //System.Diagnostics.Debug.WriteLine("ReFormatXTimeAxis");

            // Label the series with the most number of points
            Series longestSeries = tChart1.Series[0];
            foreach (Series series in tChart1.Series)
            {
                if (series.XValues.Count > longestSeries.XValues.Count)
                    longestSeries = series;

                series.Labels.Clear();
            }
            DateTime firstValue = longestSeries.XValues.AsDateTime(0);
            for (int i = 0; i < longestSeries.XValues.Count; i++)
            {
                TimeSpan span = longestSeries.XValues.AsDateTime(i).Subtract(firstValue);
                longestSeries.Labels.Add(span.ToString());
            }
        }

    }

    #region SeriesValue Class

    internal class SeriesValue
    {
        internal DateTime timeStamp;
        internal object Value;

        internal SeriesValue()
        {
            timeStamp = DateTime.Now;
            Value = null;
        }
    }

    #endregion

}